Method: PulpFileClient::FileFileRemote#list_invalid_properties

Defined in:
lib/pulp_file_client/models/file_file_remote.rb

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/pulp_file_client/models/file_file_remote.rb', line 261

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be great than or equal to 1.')
  end

  if !@ca_cert.nil? && @ca_cert.to_s.length < 1
    invalid_properties.push('invalid value for "ca_cert", the character length must be great than or equal to 1.')
  end

  if !@client_cert.nil? && @client_cert.to_s.length < 1
    invalid_properties.push('invalid value for "client_cert", the character length must be great than or equal to 1.')
  end

  if !@client_key.nil? && @client_key.to_s.length < 1
    invalid_properties.push('invalid value for "client_key", the character length must be great than or equal to 1.')
  end

  if !@proxy_url.nil? && @proxy_url.to_s.length < 1
    invalid_properties.push('invalid value for "proxy_url", the character length must be great than or equal to 1.')
  end

  if !@proxy_username.nil? && @proxy_username.to_s.length < 1
    invalid_properties.push('invalid value for "proxy_username", the character length must be great than or equal to 1.')
  end

  if !@proxy_password.nil? && @proxy_password.to_s.length < 1
    invalid_properties.push('invalid value for "proxy_password", the character length must be great than or equal to 1.')
  end

  if !@username.nil? && @username.to_s.length < 1
    invalid_properties.push('invalid value for "username", the character length must be great than or equal to 1.')
  end

  if !@password.nil? && @password.to_s.length < 1
    invalid_properties.push('invalid value for "password", the character length must be great than or equal to 1.')
  end

  if !@download_concurrency.nil? && @download_concurrency < 1
    invalid_properties.push('invalid value for "download_concurrency", must be greater than or equal to 1.')
  end

  if !@total_timeout.nil? && @total_timeout < 0
    invalid_properties.push('invalid value for "total_timeout", must be greater than or equal to 0.')
  end

  if !@connect_timeout.nil? && @connect_timeout < 0
    invalid_properties.push('invalid value for "connect_timeout", must be greater than or equal to 0.')
  end

  if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0
    invalid_properties.push('invalid value for "sock_connect_timeout", must be greater than or equal to 0.')
  end

  if !@sock_read_timeout.nil? && @sock_read_timeout < 0
    invalid_properties.push('invalid value for "sock_read_timeout", must be greater than or equal to 0.')
  end

  invalid_properties
end