Class: PulpFileClient::PatchedfileFileRepository
- Inherits:
-
Object
- Object
- PulpFileClient::PatchedfileFileRepository
- Defined in:
- lib/pulp_file_client/models/patchedfile_file_repository.rb
Overview
Serializer for File Repositories.
Instance Attribute Summary collapse
-
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
-
#description ⇒ Object
An optional description.
-
#manifest ⇒ Object
Filename to use for manifest file containing metadata for all the files.
-
#name ⇒ Object
A unique name for this repository.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#remote ⇒ Object
An optional remote to use by default when syncing.
-
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository.
-
#retain_repo_versions ⇒ Object
Retain X versions of the repository.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedfileFileRepository
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PatchedfileFileRepository
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpFileClient::PatchedfileFileRepository` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpFileClient::PatchedfileFileRepository`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'retain_repo_versions') self.retain_repo_versions = attributes[:'retain_repo_versions'] end if attributes.key?(:'retain_checkpoints') self.retain_checkpoints = attributes[:'retain_checkpoints'] end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'autopublish') self.autopublish = attributes[:'autopublish'] else self.autopublish = false end if attributes.key?(:'manifest') self.manifest = attributes[:'manifest'] else self.manifest = 'PULP_MANIFEST' end end |
Instance Attribute Details
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
37 38 39 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 37 def autopublish @autopublish end |
#description ⇒ Object
An optional description.
25 26 27 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 25 def description @description end |
#manifest ⇒ Object
Filename to use for manifest file containing metadata for all the files.
40 41 42 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 40 def manifest @manifest end |
#name ⇒ Object
A unique name for this repository.
22 23 24 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 22 def name @name end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
19 20 21 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 19 def pulp_labels @pulp_labels end |
#remote ⇒ Object
An optional remote to use by default when syncing.
34 35 36 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 34 def remote @remote end |
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.
31 32 33 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 31 def retain_checkpoints @retain_checkpoints end |
#retain_repo_versions ⇒ Object
Retain X versions of the repository. Default is null which retains all versions.
28 29 30 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 28 def retain_repo_versions @retain_repo_versions end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 288 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpFileClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 57 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 43 def self.attribute_map { :'pulp_labels' => :'pulp_labels', :'name' => :'name', :'description' => :'description', :'retain_repo_versions' => :'retain_repo_versions', :'retain_checkpoints' => :'retain_checkpoints', :'remote' => :'remote', :'autopublish' => :'autopublish', :'manifest' => :'manifest' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 83 84 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 76 def self.openapi_nullable Set.new([ :'description', :'retain_repo_versions', :'retain_checkpoints', :'remote', :'manifest' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 62 def self.openapi_types { :'pulp_labels' => :'Hash<String, String>', :'name' => :'String', :'description' => :'String', :'retain_repo_versions' => :'Integer', :'retain_checkpoints' => :'Integer', :'remote' => :'String', :'autopublish' => :'Boolean', :'manifest' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_labels == o.pulp_labels && name == o.name && description == o.description && retain_repo_versions == o.retain_repo_versions && retain_checkpoints == o.retain_checkpoints && remote == o.remote && autopublish == o.autopublish && manifest == o.manifest end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 359 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 257 def hash [pulp_labels, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, manifest].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end if !@retain_checkpoints.nil? && @retain_checkpoints < 1 invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.') end if !@manifest.nil? && @manifest.to_s.length < 1 invalid_properties.push('invalid value for "manifest", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
335 336 337 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 335 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 329 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 |
# File 'lib/pulp_file_client/models/patchedfile_file_repository.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@description.nil? && @description.to_s.length < 1 return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1 return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1 return false if !@manifest.nil? && @manifest.to_s.length < 1 true end |