Class: PulpFileClient::ContentFilesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_file_client/api/content_files_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ContentFilesApi

Returns a new instance of ContentFilesApi.



19
20
21
# File 'lib/pulp_file_client/api/content_files_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulp_file_client/api/content_files_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create(relative_path, opts = {}) ⇒ AsyncOperationResponse

Create a file content Trigger an asynchronous task to create content,optionally create new repository version.

Parameters:

  • relative_path (String)

    Path where the artifact is located relative to distributions base_path

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :repository (String)

    A URI of a repository the new content unit should be associated with.

  • :overwrite (Boolean)

    When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when &#39;repository&#39; is specified. Defaults to true.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :artifact (String)

    Artifact file representing the physical content

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

  • :downloader_config (RemoteNetworkConfig)

    Configuration for the download process (e.g., proxies, auth, timeouts). Only applicable when providing a &#39;file_url.

Returns:



36
37
38
39
# File 'lib/pulp_file_client/api/content_files_api.rb', line 36

def create(relative_path, opts = {})
  data, _status_code, _headers = create_with_http_info(relative_path, opts)
  data
end

#create_with_http_info(relative_path, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Create a file content Trigger an asynchronous task to create content,optionally create new repository version.

Parameters:

  • relative_path (String)

    Path where the artifact is located relative to distributions base_path

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :repository (String)

    A URI of a repository the new content unit should be associated with.

  • :overwrite (Boolean)

    When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when &#39;repository&#39; is specified. Defaults to true.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :artifact (String)

    Artifact file representing the physical content

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

  • :downloader_config (RemoteNetworkConfig)

    Configuration for the download process (e.g., proxies, auth, timeouts). Only applicable when providing a &#39;file_url.

Returns:

  • (Array<(AsyncOperationResponse, Integer, Hash)>)

    AsyncOperationResponse data, response status code and response headers



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/pulp_file_client/api/content_files_api.rb', line 55

def create_with_http_info(relative_path, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.create ...'
  end
  # verify the required parameter 'relative_path' is set
  if @api_client.config.client_side_validation && relative_path.nil?
    fail ArgumentError, "Missing the required parameter 'relative_path' when calling ContentFilesApi.create"
  end
  if @api_client.config.client_side_validation && relative_path.to_s.length < 1
    fail ArgumentError, 'invalid value for "relative_path" when calling ContentFilesApi.create, the character length must be great than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentFilesApi.create, the character length must be great than or equal to 1.'
  end

  # resource path
  local_var_path = '/pulp/api/v3/content/file/files/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['relative_path'] = relative_path
  form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil?
  form_params['overwrite'] = opts[:'overwrite'] if !opts[:'overwrite'].nil?
  form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil?
  form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil?
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?
  form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil?
  form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil?
  form_params['downloader_config'] = opts[:'downloader_config'] if !opts[:'downloader_config'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AsyncOperationResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ PaginatedfileFileContentResponseList

List file contents

FileContent represents a single file and its metadata, which can be added and removed from repositories.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :digest (String)

    Filter results where digest matches value

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;digest&#x60; - Digest * &#x60;-digest&#x60; - Digest (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending)

  • :orphaned_for (Float)

    Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.

  • :prn__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_label_select (String)

    Filter labels by search string

  • :q (String)

    Filter results by using NOT, AND and OR operations on other filters

  • :relative_path (String)

    Filter results where relative_path matches value

  • :relative_path__contains (String)

    Filter results where relative_path contains value

  • :relative_path__icontains (String)

    Filter results where relative_path contains value

  • :relative_path__iexact (String)

    Filter results where relative_path matches value

  • :relative_path__in (Array<String>)

    Filter results where relative_path is in a comma-separated list of values

  • :relative_path__iregex (String)

    Filter results where relative_path matches regex value

  • :relative_path__istartswith (String)

    Filter results where relative_path starts with value

  • :relative_path__regex (String)

    Filter results where relative_path matches regex value

  • :relative_path__startswith (String)

    Filter results where relative_path starts with value

  • :repository_version (String)
  • :repository_version_added (String)
  • :repository_version_removed (String)
  • :sha256 (String)
  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



156
157
158
159
# File 'lib/pulp_file_client/api/content_files_api.rb', line 156

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_with_http_info(opts = {}) ⇒ Array<(PaginatedfileFileContentResponseList, Integer, Hash)>

List file contents

FileContent represents a single file and its metadata, which can be added and removed from repositories.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :digest (String)

    Filter results where digest matches value

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;digest&#x60; - Digest * &#x60;-digest&#x60; - Digest (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending)

  • :orphaned_for (Float)

    Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.

  • :prn__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_label_select (String)

    Filter labels by search string

  • :q (String)

    Filter results by using NOT, AND and OR operations on other filters

  • :relative_path (String)

    Filter results where relative_path matches value

  • :relative_path__contains (String)

    Filter results where relative_path contains value

  • :relative_path__icontains (String)

    Filter results where relative_path contains value

  • :relative_path__iexact (String)

    Filter results where relative_path matches value

  • :relative_path__in (Array<String>)

    Filter results where relative_path is in a comma-separated list of values

  • :relative_path__iregex (String)

    Filter results where relative_path matches regex value

  • :relative_path__istartswith (String)

    Filter results where relative_path starts with value

  • :relative_path__regex (String)

    Filter results where relative_path matches regex value

  • :relative_path__startswith (String)

    Filter results where relative_path starts with value

  • :repository_version (String)
  • :repository_version_added (String)
  • :repository_version_removed (String)
  • :sha256 (String)
  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/pulp_file_client/api/content_files_api.rb', line 191

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.list ...'
  end
  allowable_values = ["-digest", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-relative_path", "-timestamp_of_interest", "-upstream_id", "digest", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "relative_path", "timestamp_of_interest", "upstream_id"]
  if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/pulp/api/v3/content/file/files/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'digest'] = opts[:'digest'] if !opts[:'digest'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil?
  query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil?
  query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil?
  query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil?
  query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil?
  query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil?
  query_params[:'relative_path__contains'] = opts[:'relative_path__contains'] if !opts[:'relative_path__contains'].nil?
  query_params[:'relative_path__icontains'] = opts[:'relative_path__icontains'] if !opts[:'relative_path__icontains'].nil?
  query_params[:'relative_path__iexact'] = opts[:'relative_path__iexact'] if !opts[:'relative_path__iexact'].nil?
  query_params[:'relative_path__in'] = @api_client.build_collection_param(opts[:'relative_path__in'], :csv) if !opts[:'relative_path__in'].nil?
  query_params[:'relative_path__iregex'] = opts[:'relative_path__iregex'] if !opts[:'relative_path__iregex'].nil?
  query_params[:'relative_path__istartswith'] = opts[:'relative_path__istartswith'] if !opts[:'relative_path__istartswith'].nil?
  query_params[:'relative_path__regex'] = opts[:'relative_path__regex'] if !opts[:'relative_path__regex'].nil?
  query_params[:'relative_path__startswith'] = opts[:'relative_path__startswith'] if !opts[:'relative_path__startswith'].nil?
  query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil?
  query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil?
  query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil?
  query_params[:'sha256'] = opts[:'sha256'] if !opts[:'sha256'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedfileFileContentResponseList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(file_file_content_href, opts = {}) ⇒ FileFileContentResponse

Inspect a file content

FileContent represents a single file and its metadata, which can be added and removed from repositories.

Parameters:

  • file_file_content_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



273
274
275
276
# File 'lib/pulp_file_client/api/content_files_api.rb', line 273

def read(file_file_content_href, opts = {})
  data, _status_code, _headers = read_with_http_info(file_file_content_href, opts)
  data
end

#read_with_http_info(file_file_content_href, opts = {}) ⇒ Array<(FileFileContentResponse, Integer, Hash)>

Inspect a file content

FileContent represents a single file and its metadata, which can be added and removed from repositories.

Parameters:

  • file_file_content_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(FileFileContentResponse, Integer, Hash)>)

    FileFileContentResponse data, response status code and response headers



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pulp_file_client/api/content_files_api.rb', line 286

def read_with_http_info(file_file_content_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.read ...'
  end
  # verify the required parameter 'file_file_content_href' is set
  if @api_client.config.client_side_validation && file_file_content_href.nil?
    fail ArgumentError, "Missing the required parameter 'file_file_content_href' when calling ContentFilesApi.read"
  end
  # resource path
  local_var_path = '{file_file_content_href}'.sub('{' + 'file_file_content_href' + '}', CGI.escape(file_file_content_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'FileFileContentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.read",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#set_label(file_file_content_href, set_label, opts = {}) ⇒ SetLabelResponse

Set a label Set a single pulp_label on the object to a specific value or null.

Parameters:

  • file_file_content_href (String)
  • set_label (SetLabel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



344
345
346
347
# File 'lib/pulp_file_client/api/content_files_api.rb', line 344

def set_label(file_file_content_href, set_label, opts = {})
  data, _status_code, _headers = set_label_with_http_info(file_file_content_href, set_label, opts)
  data
end

#set_label_with_http_info(file_file_content_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>

Set a label Set a single pulp_label on the object to a specific value or null.

Parameters:

  • file_file_content_href (String)
  • set_label (SetLabel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(SetLabelResponse, Integer, Hash)>)

    SetLabelResponse data, response status code and response headers



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/pulp_file_client/api/content_files_api.rb', line 356

def set_label_with_http_info(file_file_content_href, set_label, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.set_label ...'
  end
  # verify the required parameter 'file_file_content_href' is set
  if @api_client.config.client_side_validation && file_file_content_href.nil?
    fail ArgumentError, "Missing the required parameter 'file_file_content_href' when calling ContentFilesApi.set_label"
  end
  # verify the required parameter 'set_label' is set
  if @api_client.config.client_side_validation && set_label.nil?
    fail ArgumentError, "Missing the required parameter 'set_label' when calling ContentFilesApi.set_label"
  end
  # resource path
  local_var_path = '{file_file_content_href}set_label/'.sub('{' + 'file_file_content_href' + '}', CGI.escape(file_file_content_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label)

  # return_type
  return_type = opts[:debug_return_type] || 'SetLabelResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.set_label",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#unset_label(file_file_content_href, unset_label, opts = {}) ⇒ UnsetLabelResponse

Unset a label Unset a single pulp_label on the object.

Parameters:

  • file_file_content_href (String)
  • unset_label (UnsetLabel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



421
422
423
424
# File 'lib/pulp_file_client/api/content_files_api.rb', line 421

def unset_label(file_file_content_href, unset_label, opts = {})
  data, _status_code, _headers = unset_label_with_http_info(file_file_content_href, unset_label, opts)
  data
end

#unset_label_with_http_info(file_file_content_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>

Unset a label Unset a single pulp_label on the object.

Parameters:

  • file_file_content_href (String)
  • unset_label (UnsetLabel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(UnsetLabelResponse, Integer, Hash)>)

    UnsetLabelResponse data, response status code and response headers



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/pulp_file_client/api/content_files_api.rb', line 433

def unset_label_with_http_info(file_file_content_href, unset_label, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.unset_label ...'
  end
  # verify the required parameter 'file_file_content_href' is set
  if @api_client.config.client_side_validation && file_file_content_href.nil?
    fail ArgumentError, "Missing the required parameter 'file_file_content_href' when calling ContentFilesApi.unset_label"
  end
  # verify the required parameter 'unset_label' is set
  if @api_client.config.client_side_validation && unset_label.nil?
    fail ArgumentError, "Missing the required parameter 'unset_label' when calling ContentFilesApi.unset_label"
  end
  # resource path
  local_var_path = '{file_file_content_href}unset_label/'.sub('{' + 'file_file_content_href' + '}', CGI.escape(file_file_content_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label)

  # return_type
  return_type = opts[:debug_return_type] || 'UnsetLabelResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.unset_label",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#upload(relative_path, opts = {}) ⇒ FileContentUploadResponse

Upload a File synchronously. Synchronously upload a File.

Parameters:

  • relative_path (String)

    Path where the artifact is located relative to distributions base_path

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :overwrite (Boolean)

    When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when &#39;repository&#39; is specified. Defaults to true.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :artifact (String)

    Artifact file representing the physical content

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

  • :downloader_config (RemoteNetworkConfig)

    Configuration for the download process (e.g., proxies, auth, timeouts). Only applicable when providing a &#39;file_url.

Returns:



504
505
506
507
# File 'lib/pulp_file_client/api/content_files_api.rb', line 504

def upload(relative_path, opts = {})
  data, _status_code, _headers = upload_with_http_info(relative_path, opts)
  data
end

#upload_with_http_info(relative_path, opts = {}) ⇒ Array<(FileContentUploadResponse, Integer, Hash)>

Upload a File synchronously. Synchronously upload a File.

Parameters:

  • relative_path (String)

    Path where the artifact is located relative to distributions base_path

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :overwrite (Boolean)

    When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when &#39;repository&#39; is specified. Defaults to true.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :artifact (String)

    Artifact file representing the physical content

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

  • :downloader_config (RemoteNetworkConfig)

    Configuration for the download process (e.g., proxies, auth, timeouts). Only applicable when providing a &#39;file_url.

Returns:

  • (Array<(FileContentUploadResponse, Integer, Hash)>)

    FileContentUploadResponse data, response status code and response headers



522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
# File 'lib/pulp_file_client/api/content_files_api.rb', line 522

def upload_with_http_info(relative_path, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentFilesApi.upload ...'
  end
  # verify the required parameter 'relative_path' is set
  if @api_client.config.client_side_validation && relative_path.nil?
    fail ArgumentError, "Missing the required parameter 'relative_path' when calling ContentFilesApi.upload"
  end
  if @api_client.config.client_side_validation && relative_path.to_s.length < 1
    fail ArgumentError, 'invalid value for "relative_path" when calling ContentFilesApi.upload, the character length must be great than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentFilesApi.upload, the character length must be great than or equal to 1.'
  end

  # resource path
  local_var_path = '/pulp/api/v3/content/file/files/upload/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['relative_path'] = relative_path
  form_params['overwrite'] = opts[:'overwrite'] if !opts[:'overwrite'].nil?
  form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil?
  form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil?
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?
  form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil?
  form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil?
  form_params['downloader_config'] = opts[:'downloader_config'] if !opts[:'downloader_config'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'FileContentUploadResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentFilesApi.upload",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentFilesApi#upload\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end